@@ -1,6 +1,10 @@
 /*
  *  agShell
- *  $Id: agShell.c,v 4.11 2006/06/24 23:36:07 bkorb Exp $
+ *  $Id: agShell.c,v 4.19 2006/11/27 01:52:22 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-11-26 15:09:07 bkorb"
+ *  Last Committed:    $Date: 2006/11/27 01:52:22 $
+ *
  *  Manage a server shell process
  */
 
@@ -33,7 +37,7 @@
 
  pid_t openServerFP( tpfPair* pfPair, tCC** ppArgs ) { return NOPROCESS; }
 
- char* runShell( const char* pzCmd ) {
+ char* runShell( char const* pzCmd ) {
      char* pz;
      AGDUPSTR( pz, pzCmd, "dummy shell command" );
      return pz;
@@ -52,7 +56,7 @@ static tCC     logIntroFmt[] = "\n\n* * * * LOG ENTRY %d * * * *\n";
 
 tSCC   zCmdFmt[]   = "cd %s\n%s\n\necho\necho %s - %d\n";
 
-const char* pzLastCmd = NULL;
+char const* pzLastCmd = NULL;
 
 /* = = = START-STATIC-FORWARD = = = */
 /* static forward declarations maintained by :mkfwd */
@@ -113,7 +117,7 @@ sigHandler( int signo )
 
     (void)fputs( "\nLast command issued:\n", pfTrace );
     {
-        const char* pz = (pzLastCmd == NULL)
+        char const* pz = (pzLastCmd == NULL)
             ? "?? unknown ??\n" : pzLastCmd;
         fprintf( pfTrace, zCmdFmt, pCurDir, pz, zShDone, logCount );
     }
@@ -132,12 +136,11 @@ serverSetup( void )
     {
         static int doneOnce = 0;
         if (doneOnce++ == 0) {
-            char* p = malloc( MAXPATHLEN );
+            char* p = malloc( AG_PATH_MAX );
             if (p == NULL)
                 AG_ABEND( "cannot allocate path name" );
 
-            (void)atexit( &closeServer );
-            pCurDir = (tpChar)getcwd( p, MAXPATHLEN );
+            pCurDir = (tpChar)getcwd( p, AG_PATH_MAX );
 
             if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL)
                 fputs( "\nServer First Start\n", pfTrace );
@@ -162,7 +165,7 @@ serverSetup( void )
         pzLastCmd = zShellInit;
         if (pzPid == NULL)
             pzPid = zShellInit + strlen(zShellInit);
-        sprintf( pzPid, "%d\n", getpid() );
+        sprintf( pzPid, "%u\n", (unsigned int)getpid() );
         fprintf( serverPair.pfWrite, zCmdFmt, pCurDir, pzLastCmd,
                  zShDone, ++logCount );
 
@@ -240,26 +243,36 @@ chainOpen( int       stdinFd,
             pzShell = pzShellProgram;
 
         else {
-            pzShell = getenv( zShellEnv );
-            if (pzShell == NULL)
-                pzShell = "sh";
-            pzShellProgram = pzShell;
-        }
+            static char const sh_z[] = "sh";
+            static char const bin_sh[] = "/bin/sh";
 
-        /*
-         *  Disallow 'csh' and 'tcsh', or any other *csh variation.
-         *  They invariably lead to problems.
-         */
-        {
-            size_t l = strlen( pzShell );
-            if (  (l > 2)
-               && (strcmp( pzShell + l - 3, "csh" ) == 0)  )  {
-                tSCC zBadShell[] =
-                    "Your shell is '%s'.  AutoGen will attempt to use 'sh'\n";
+            pzShellProgram = getenv( zShellEnv );
+            if (pzShellProgram == NULL) {
+#               ifdef __sun
+                static char const xpg_sh[] = "/usr/xpg4/bin/sh";
+#               endif
 
-                fprintf( stdout, zBadShell, pzShell );
-                pzShell = "sh";
+            no_useful_SHELL:
+#               ifdef __sun
+                if (access(xpg_sh, X_OK) == 0)
+                    pzShellProgram = xpg_sh;
+                else
+#               endif
+                    if (access(bin_sh, X_OK) == 0)
+                         pzShellProgram = bin_sh;
+                    else pzShellProgram = sh_z;
+
+            } else {
+                char const * pze = pzShellProgram + strlen(pzShellProgram);
+                if (  ((pze - pzShellProgram) > 2)
+                   && (pze[-3] == 'c')
+                   && (pze[-2] == 's')
+                   && (pze[-1] == 'h'))  {
+                    goto no_useful_SHELL;
+                }
             }
+            putenv( aprf( "%s=%s", zShellEnv, pzShellProgram ));
+            pzShell = pzShellProgram;
         }
 
         *ppArgs = pzShell;
@@ -275,23 +288,6 @@ chainOpen( int       stdinFd,
         return -1;
     }
 
-#if defined( DEBUG_ENABLED )
-    if (OPT_VALUE_TRACE >= TRACE_EVERYTHING) {
-        tSCC   zPath[] = "PATH";
-        tCC*   pzPath  = getenv( zPath );
-
-        if (pzPath == NULL)
-            pzPath = pzShell;
-
-        else {
-            pzPath = pathfind( pzPath, pzShell, "rxs" );
-            if (pzPath == NULL)
-                pzPath = pzShell;
-        }
-
-        fprintf( pfTrace, "Starting shell `%s'\n", pzPath );
-    }
-#endif
     fflush( stdout );
     fflush( stderr );
     fflush( pfTrace );
@@ -316,7 +312,7 @@ chainOpen( int       stdinFd,
         close( stdinFd );
         close( stdoutPair.writeFd );
         if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL)
-            fprintf( pfTrace, "Server shell is pid %d\n", chId );
+            fprintf(pfTrace, "Server shell is pid %u\n", (unsigned int)chId);
 
         fflush( pfTrace );
         return stdoutPair.readFd;
@@ -351,7 +347,7 @@ chainOpen( int       stdinFd,
      *  Make the output file unbuffered only.
      *  We do not want to wait for shell output buffering.
      */
-    setvbuf( stdout, NULL, _IONBF, 0 );
+    setvbuf(stdout, NULL, _IONBF, (size_t)0);
 
     if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL) {
         fprintf( pfTrace, "Server shell %s starts\n", pzShell );
@@ -451,8 +447,8 @@ loadData( void )
          *  Set a timeout so we do not wait forever.  Sometimes we don't wait
          *  at all and we should.  Retry in those cases (but not on EOF).
          */
-        alarm( OPT_VALUE_TIMEOUT );
-        line_p = fgets( zLine, sizeof( zLine ), serverPair.pfRead );
+        alarm( (unsigned int)OPT_VALUE_TIMEOUT );
+        line_p = fgets(zLine, (int)sizeof(zLine), serverPair.pfRead);
         alarm( 0 );
 
         if (line_p == NULL) {
@@ -520,7 +516,7 @@ loadData( void )
     if (OPT_VALUE_TRACE >= TRACE_SERVER_SHELL) {
         fprintf( pfTrace, "\n= = = RESULT %d bytes:\n%s%s\n"
                  "= = = = = = = = = = = = = = =\n",
-                 textSize, pzText, zLine );
+                 (int)textSize, pzText, zLine );
     }
 
     *pzScan  = NUL;
@@ -535,7 +531,7 @@ loadData( void )
  *  we will shoot it and restart one later.
  */
 LOCAL char*
-runShell( const char*  pzCmd )
+runShell( char const*  pzCmd )
 {
     tSCC zCmdFail[] = "CLOSING SHELL SERVER - command failure:\n\t%s\n";
 
@@ -608,7 +604,6 @@ runShell( const char*  pzCmd )
 /*
  * Local Variables:
  * mode: C
- * tab-width: 4
  * c-file-style: "stroustrup"
  * indent-tabs-mode: nil
  * End:
