@@ -1,10 +1,10 @@
 
 /*
  *  agUtils.c
- *  $Id: agUtils.c,v 4.12 2006/09/24 02:58:59 bkorb Exp $
+ *  $Id: agUtils.c,v 4.13 2006/12/10 19:41:26 bkorb Exp $
  *
- *  Time-stamp:        "2006-09-23 19:56:07 bkorb"
- *  Last Committed:    $Date: 2006/09/24 02:58:59 $
+ *  Time-stamp:        "2006-12-10 11:02:27 bkorb"
+ *  Last Committed:    $Date: 2006/12/10 19:41:26 $
  *
  *  This is the main routine for autogen.
  */
@@ -255,7 +255,7 @@ getDefine( tCC* pzDefName, ag_bool check_env )
                 *pzEq = '=';
 
             if (res == 0)
-                return (pzEq != NULL) ? pzEq+1 : "";
+                return (pzEq != NULL) ? pzEq+1 : zNil;
         }
     }
     return check_env ? getenv( pzDefName ) : NULL;
