@@ -1,7 +1,11 @@
 
 /*
  *  autogen.c
- *  $Id: autogen.c,v 4.12 2006/07/22 04:50:19 bkorb Exp $
+ *  $Id: autogen.c,v 4.18 2006/12/15 03:01:10 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-12-14 18:17:30 bkorb"
+ *  Last Committed:    $Date: 2006/12/15 03:01:10 $
+ *
  *  This is the main routine for autogen.
  */
 
@@ -32,6 +36,8 @@ tSCC* apzStateName[] = { STATE_TABLE };
 #undef _State_
 
 static sigjmp_buf  abendJumpEnv;
+static int         abendJumpSignal = 0;
+
 typedef void (sighandler_proc_t)( int sig );
 static sighandler_proc_t ignoreSignal, abendSignal;
 
@@ -92,11 +98,14 @@ main( int    argc,
       char** argv )
 {
     pfTrace = stderr;
-    {
-        int signo = sigsetjmp( abendJumpEnv, 0 );
-        if (signo != 0)
-            signalExit( signo );
-    }
+
+    /*
+     *  IF sigsetjmp returns with a signal number,
+     *  THEN you cannot capture the value portably.  So, the jumper has
+     *  stashed it for use now.
+     */
+    if (sigsetjmp( abendJumpEnv, 0 ) != 0)
+        signalExit( abendJumpSignal );
 
     signalSetup( ignoreSignal, abendSignal );
 
@@ -142,7 +151,8 @@ signalExit( int sig )
         tSCC zAt[]  = "processing template %s\n"
                       "            on line %d\n"
                       "       for function %s (%d)\n";
-        int line, fnCd;
+        int line;
+        teFuncType fnCd;
         tCC* pzFn;
         tCC* pzFl;
 
@@ -152,7 +162,8 @@ signalExit( int sig )
             fnCd = -1;
 
         } else {
-            int f = (pCurMacro->funcCode > FUNC_CT)
+            teFuncType f =
+                (pCurMacro->funcCode > FUNC_CT)
                     ? FTYP_SELECT : pCurMacro->funcCode;
             pzFn = apzFuncNames[ f ];
             line = pCurMacro->lineNo;
@@ -176,6 +187,7 @@ signalExit( int sig )
 static void
 abendSignal( int sig )
 {
+    abendJumpSignal = sig;
     siglongjmp( abendJumpEnv, sig );
 }
 
@@ -213,6 +225,7 @@ doneCheck( void )
     ag_scm_c_eval_string_from_file_line(
         "(if (> (string-length shell-cleanup) 0)"
         " (shell shell-cleanup) )", __FILE__, __LINE__ );
+    closeServer();
 #endif
 
     fflush( stdout );
@@ -223,7 +236,6 @@ doneCheck( void )
             int status;
 
             pclose( pfTrace );
-            closeServer();
             while (wait( &status ) > 0)  ;
         }
         else fclose( pfTrace );
@@ -306,7 +318,7 @@ doneCheck( void )
     }
 
     do {
-        unsigned long pos = ftell( stderr );
+        long pos = ftell( stderr );
         char* pz;
 
         /*
@@ -316,8 +328,8 @@ doneCheck( void )
             break;
         pz = AGALOC( pos, "stderr redirected text" );
         rewind( stderr );
-        fread(  pz, 1, pos, stderr );
-        fwrite( pz, 1, pos, stdout );
+        fread(  pz, (size_t)1, (size_t)pos, stderr );
+        fwrite( pz, (size_t)1, (size_t)pos, stdout );
         AGFREE( pz );
     } while (0);
 
@@ -473,11 +485,53 @@ signalSetup( sighandler_proc_t* chldHandler,
 #  include <compat/strsignal.c>
 #endif
 
+LOCAL void *
+ao_malloc (size_t sz)
+{
+    void * res = malloc(sz);
+    if (res == NULL) {
+        fprintf(stderr, "malloc of %d bytes failed\n", (int)sz);
+        exit( EXIT_FAILURE );
+    }
+    return res;
+}
+
+
+LOCAL void *
+ao_realloc (void *p, size_t sz)
+{
+    void * res = realloc(p, sz);
+    if (res == NULL) {
+        fprintf(stderr, "realloc of %d bytes at 0x%p failed\n", (int)sz, p);
+        exit( EXIT_FAILURE );
+    }
+    return res;
+}
+
+
+LOCAL void
+ao_free (void *p)
+{
+    if (p != NULL)
+        free(p);
+}
+
+
+LOCAL char *
+ao_strdup (char const * str)
+{
+    char * res = strdup(str);
+    if (res == NULL) {
+        fprintf(stderr, "strdup of %d byte string failed\n", (int)strlen(str));
+        exit( EXIT_FAILURE );
+    }
+    return res;
+}
+
 /*
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/autogen.c */
