@@ -1,6 +1,9 @@
 
 /*
- *  $Id: funcCase.c,v 4.10 2006/06/24 23:36:07 bkorb Exp $
+ *  $Id: funcCase.c,v 4.15 2006/12/10 19:41:26 bkorb Exp $
+ *
+ *  Time-stamp:        "2006-12-10 11:11:54 bkorb"
+ *  Last Committed:    $Date: 2006/12/10 19:41:26 $
  *
  *  This module implements the CASE text function.
  */
@@ -488,12 +491,12 @@ Select_Match( tCC* pzText, tCC* pzMatch )
      */
     if (pCurMacro->funcPrivate == NULL) {
         regex_t*  pRe = AGALOC( sizeof( *pRe ), "select match re" );
-        compile_re( pRe, (char*)pzMatch, pCurMacro->res );
+        compile_re(pRe, (char*)pzMatch, (int)pCurMacro->res);
         pCurMacro->funcPrivate = (void*)pRe;
     }
 
-    if (regexec( (regex_t*)pCurMacro->funcPrivate, pzText, 0,
-                 NULL, 0 ) != 0)
+    if (regexec((regex_t*)pCurMacro->funcPrivate, pzText, (size_t)0,
+                 NULL, 0) != 0)
         return FAILURE;
     return SUCCESS;
 }
@@ -506,8 +509,8 @@ ag_scm_string_has_match_p( SCM text, SCM substr )
 
     compile_re( &re, ag_scm2zchars( substr, "match expr" ), REG_EXTENDED );
 
-    if (regexec( &re, ag_scm2zchars( text, "text to match" ), 0,
-                 NULL, 0 ) == 0)
+    if (regexec(&re, ag_scm2zchars( text, "text to match" ), (size_t)0,
+                 NULL, 0) == 0)
          res = SCM_BOOL_T;
     else res = SCM_BOOL_F;
     regfree( &re );
@@ -525,7 +528,7 @@ ag_scm_string_has_eqv_match_p( SCM text, SCM substr )
 
     compile_re( &re, pzSubstr, REG_EXTENDED | REG_ICASE );
 
-    if (regexec( &re, pzText, 0, NULL, 0 ) == 0)
+    if (regexec(&re, pzText, (size_t)0, NULL, 0) == 0)
          res = SCM_BOOL_T;
     else res = SCM_BOOL_F;
     regfree( &re );
@@ -570,11 +573,11 @@ Select_Match_End( tCC* pzText, tCC* pzMatch )
      */
     if (pCurMacro->funcPrivate == NULL) {
         regex_t*  pRe = AGALOC( sizeof( *pRe ), "select match end re" );
-        compile_re( pRe, (char*)pzMatch, pCurMacro->res );
+        compile_re(pRe, (char*)pzMatch, (int)pCurMacro->res);
         pCurMacro->funcPrivate = (void*)pRe;
     }
 
-    if (regexec( (regex_t*)pCurMacro->funcPrivate, pzText, 2, m, 0 ) != 0)
+    if (regexec((regex_t*)pCurMacro->funcPrivate, pzText, (size_t)2, m, 0) != 0)
         return FAILURE;
     if (m[0].rm_eo != strlen( pzText ))
         return FAILURE;
@@ -592,7 +595,7 @@ ag_scm_string_end_match_p( SCM text, SCM substr )
 
     compile_re( &re, pzSubstr, REG_EXTENDED );
 
-    if (regexec( &re, pzText, 2, m, 0 ) != 0)
+    if (regexec(&re, pzText, (size_t)2, m, 0) != 0)
          res = SCM_BOOL_F;
     else if (m[0].rm_eo != strlen( pzText ))
          res = SCM_BOOL_F;
@@ -614,7 +617,7 @@ ag_scm_string_end_eqv_match_p( SCM text, SCM substr )
 
     compile_re( &re, pzSubstr, REG_EXTENDED | REG_ICASE );
 
-    if (regexec( &re, pzText, 2, m, 0 ) != 0)
+    if (regexec(&re, pzText, (size_t)2, m, 0) != 0)
          res = SCM_BOOL_F;
     else if (m[0].rm_eo != strlen( pzText ))
          res = SCM_BOOL_F;
@@ -662,11 +665,11 @@ Select_Match_Start( tCC* pzText, tCC* pzMatch )
      */
     if (pCurMacro->funcPrivate == NULL) {
         regex_t*  pRe = AGALOC( sizeof( *pRe ), "select match start re" );
-        compile_re( pRe, (char*)pzMatch, pCurMacro->res );
+        compile_re(pRe, (char*)pzMatch, (int)pCurMacro->res);
         pCurMacro->funcPrivate = (void*)pRe;
     }
 
-    if (regexec( (regex_t*)pCurMacro->funcPrivate, pzText, 2, m, 0 ) != 0)
+    if (regexec((regex_t*)pCurMacro->funcPrivate, pzText, (size_t)2, m, 0) != 0)
         return FAILURE;
     if (m[0].rm_so != 0)
         return FAILURE;
@@ -684,7 +687,7 @@ ag_scm_string_start_match_p( SCM text, SCM substr )
 
     compile_re( &re, pzSubstr, REG_EXTENDED );
 
-    if (regexec( &re, pzText, 2, m, 0 ) != 0)
+    if (regexec(&re, pzText, (size_t)2, m, 0) != 0)
          res = SCM_BOOL_F;
     else if (m[0].rm_so != 0)
          res = SCM_BOOL_F;
@@ -706,7 +709,7 @@ ag_scm_string_start_eqv_match_p( SCM text, SCM substr )
 
     compile_re( &re, pzSubstr, REG_EXTENDED | REG_ICASE );
 
-    if (regexec( &re, pzText, 2, m, 0 ) != 0)
+    if (regexec(&re, pzText, (size_t)2, m, 0) != 0)
          res = SCM_BOOL_F;
     else if (m[0].rm_so != 0)
          res = SCM_BOOL_F;
@@ -760,11 +763,11 @@ Select_Match_Full( tCC* pzText, tCC* pzMatch )
             fprintf( pfTrace, "Compiling ``%s'' with bits 0x%lX\n",
                      pzMatch, pCurMacro->res );
         }
-        compile_re( pRe, (char*)pzMatch, pCurMacro->res );
+        compile_re(pRe, (char*)pzMatch, (int)pCurMacro->res);
         pCurMacro->funcPrivate = pRe;
     }
 
-    if (regexec( (regex_t*)pCurMacro->funcPrivate, pzText, 2, m, 0 ) != 0)
+    if (regexec((regex_t*)pCurMacro->funcPrivate, pzText, (size_t)2, m, 0) != 0)
         return FAILURE;
 
     if (  (m[0].rm_eo != strlen( pzText ))
@@ -784,7 +787,7 @@ ag_scm_string_match_p( SCM text, SCM substr )
 
     compile_re( &re, pzSubstr, REG_EXTENDED );
 
-    if (regexec( &re, pzText, 2, m, 0 ) != 0)
+    if (regexec(&re, pzText, (size_t)2, m, 0) != 0)
          res = SCM_BOOL_F;
     else if (  (m[0].rm_eo != strlen( pzText ))
             || (m[0].rm_so != 0) )
@@ -807,7 +810,7 @@ ag_scm_string_eqv_match_p( SCM text, SCM substr )
 
     compile_re( &re, pzSubstr, REG_EXTENDED | REG_ICASE );
 
-    if (regexec( &re, pzText, 2, m, 0 ) != 0)
+    if (regexec(&re, pzText, (size_t)2, m, 0) != 0)
          res = SCM_BOOL_F;
     else if (  (m[0].rm_eo != strlen( pzText ))
             || (m[0].rm_so != 0) )
@@ -838,13 +841,13 @@ Select_Match_Always( tCC* pzText, tCC* pzMatch )
 static tSuccess
 Select_Match_Existence( tCC* pzText, tCC* pzMatch )
 {
-    return (pzText != zDefaultNil) ? SUCCESS : FAILURE;
+    return (pzText != zNil) ? SUCCESS : FAILURE;
 }
 
 static tSuccess
 Select_Match_NonExistence( tCC* pzText, tCC* pzMatch )
 {
-    return (pzText == zDefaultNil) ? SUCCESS : FAILURE;
+    return (pzText == zNil) ? SUCCESS : FAILURE;
 }
 
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -1157,9 +1160,9 @@ mLoad_Case( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 static tMacro*
 mLoad_Select( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
 {
-    const char*    pzScan = *ppzScan;  /* text after macro */
+    char const*    pzScan = *ppzScan;  /* text after macro */
     char*          pzCopy = pT->pNext; /* next text dest   */
-    const char*    pzSrc  = (char*)pMac->ozText; /* macro text */
+    char const*    pzSrc  = (char*)pMac->ozText; /* macro text */
     long           srcLen = pMac->res;           /* macro len  */
 
     tSCC zInvSel[] = "Invalid selection clause";
@@ -1252,7 +1255,7 @@ mLoad_Select( tTemplate* pT, tMacro* pMac, tCC** ppzScan )
         AG_ABEND_IN( pT, pMac, zInvSel );
 
     while (isspace(*pzSrc)) pzSrc++;
-    srcLen -= pzSrc - (const char*)pMac->ozText;
+    srcLen -= pzSrc - (char const*)pMac->ozText;
     if (srcLen <= 0)
         AG_ABEND_IN( pT, pMac, zInvSel );
 
@@ -1317,7 +1320,6 @@ mUnload_Select( tMacro* pMac )
  * Local Variables:
  * mode: C
  * c-file-style: "stroustrup"
- * tab-width: 4
  * indent-tabs-mode: nil
  * End:
  * end of agen5/funcCase.c */
