@@ -1,9 +1,9 @@
 
 /*
- *  $Id: tpLoad.c,v 4.15 2006/12/10 16:43:00 bkorb Exp $
+ *  $Id: tpLoad.c,v 4.19 2007/01/27 15:07:56 bkorb Exp $
  *
- * Time-stamp:        "2006-12-02 10:33:18 bkorb"
- * Last Committed:    $Date: 2006/12/10 16:43:00 $
+ * Time-stamp:        "2007-01-20 11:59:09 bkorb"
+ * Last Committed:    $Date: 2007/01/27 15:07:56 $
  *
  *  This module will load a template and return a template structure.
  */
@@ -415,7 +415,8 @@ unloadTemplate( tTemplate* pT )
 LOCAL void
 cleanup( tTemplate* pTF )
 {
-#if ! defined(DEBUG_ENABLED)
+    optionFree(&autogenOptions);
+
     for (;;) {
         tTemplate* pT = pNamedTplList;
         if (pT == NULL)
@@ -430,7 +431,6 @@ cleanup( tTemplate* pTF )
     ag_scmStrings_deinit();
 
     manageAllocatedData( NULL );
-#endif
 }
 
 /*
