@@ -1,12 +1,11 @@
-
 /*
  *  agTempl.c
- *  $Id: tpProcess.c,v 4.12 2006/09/24 02:59:00 bkorb Exp $
+ *  $Id: tpProcess.c,v 4.16 2007/01/07 22:22:01 bkorb Exp $
  *
  *  Parse and process the template data descriptions
  *
- * Time-stamp:        "2006-09-23 19:48:42 bkorb"
- * Last Committed:    $Date: 2006/09/24 02:59:00 $
+ * Time-stamp:        "2007-01-02 11:42:56 bkorb"
+ * Last Committed:    $Date: 2007/01/07 22:22:01 $
  *
  */
 
@@ -97,31 +96,30 @@ static void
 doStdoutTemplate( tTemplate* pTF )
 {
     tSCC zNoSfx[] = "* NONE *";
-    tSCC zBadR[]  = "%sBogus return from setjmp:  %d\n";
-    int  jmpcode  = setjmp( fileAbort );
+    tSCC zBadR[]  = "%sBogus return from setjmp\n";
     SCM  res;
     tCC* pzRes;
 
     pzLastScheme = NULL; /* We cannot be in Scheme processing */
 
-    switch (jmpcode) {
+    switch (setjmp (fileAbort)) {
     case SUCCESS:
         break;
 
     case PROBLEM:
         if (*pzOopsPrefix != NUL) {
             fprintf( stdout, "%soutput was abandoned\n", pzOopsPrefix );
-            pzOopsPrefix = "";
+            pzOopsPrefix = zNil;
         }
         fclose( stdout );
         return;
 
     default:
         if (*pzOopsPrefix != NUL) {
-            fprintf( stdout, zBadR, pzOopsPrefix, jmpcode );
-            pzOopsPrefix = "";
+            fprintf( stdout, zBadR, pzOopsPrefix );
+            pzOopsPrefix = zNil;
         } else {
-            fprintf( pfTrace, zBadR+2, jmpcode );
+            fprintf( pfTrace, zBadR+2 );
         }
 
     case FAILURE:
@@ -158,10 +156,10 @@ doStdoutTemplate( tTemplate* pTF )
         res   = ag_scm_out_pop( SCM_BOOL_T );
         pzRes = AG_SCM_CHARS( res );
 
-        if (strneqvcmp( pzRes, zCont, sizeof( zCont ) - 1) != 0)
+        if (strneqvcmp( pzRes, zCont, (int)sizeof(zCont) - 1) != 0)
             fputs( "Content-Type: text/html\n\n", stdout );
 
-        fwrite( pzRes, AG_SCM_STRLEN( res ), 1, stdout );
+        fwrite( pzRes, AG_SCM_STRLEN(res), (size_t)1, stdout );
     }
 
     fclose( stdout );
@@ -185,7 +183,6 @@ processTemplate( tTemplate* pTF )
 
     for (;;) {
         tOutSpec*  pOS    = pOutSpecList;
-        int        jumpCd = setjmp( fileAbort );
 
         /*
          * We cannot be in Scheme processing.  We've either just started
@@ -198,7 +195,8 @@ processTemplate( tTemplate* pTF )
         /*
          *  HOW was that we got here?
          */
-        if (jumpCd == SUCCESS) {
+        switch (setjmp( fileAbort )) {
+        case SUCCESS:
             /*
              *  Set the output file name buffer.
              *  It may get switched inside openOutFile.
@@ -216,15 +214,24 @@ processTemplate( tTemplate* pTF )
             do  {
                 closeOutput( AG_FALSE );  /* keep output */
             } while (pCurFp->pPrev != NULL);
-        }
+            break;
 
-        else {
-            if ((jumpCd != PROBLEM) && (jumpCd != FAILURE)) {
-                fprintf( pfTrace, "%sBogus return from setjmp:  %d\n",
-                         pzOopsPrefix, jumpCd );
-                pzOopsPrefix = "";
-            }
+        case PROBLEM:
+            /*
+             *  We got here by a long jump.  Close/purge the open files.
+             */
+            do  {
+                closeOutput( AG_TRUE );  /* discard output */
+            } while (pCurFp->pPrev != NULL);
+            pzLastScheme = NULL; /* "problem" implies requested exit. */
+            break;
 
+        default:
+            fprintf( pfTrace, "%sBogus return from setjmp\n", pzOopsPrefix );
+            pzOopsPrefix = zNil;
+            /* FALLTHROUGH */
+
+        case FAILURE:
             /*
              *  We got here by a long jump.  Close/purge the open files.
              */
@@ -235,10 +242,8 @@ processTemplate( tTemplate* pTF )
             /*
              *  On failure (or unknown jump type), we quit the program, too.
              */
-            if (jumpCd != PROBLEM) {
-                procState = PROC_STATE_ABORTING;
-                exit( EXIT_FAILURE );
-            }
+            procState = PROC_STATE_ABORTING;
+            exit( EXIT_FAILURE );
         }
 
         /*
@@ -316,7 +321,7 @@ openOutFile( tOutSpec* pOutSpec, tFpStack* pStk )
      *  Remove any suffixes in the last file name
      */
     {
-        char   z[ MAXPATHLEN ];
+        char   z[ AG_PATH_MAX ];
         tCC*   pS = strrchr( pzDefFile, '/' );
         char*  pE;
         if (pS++ == NULL)
