@@ -1,7 +1,7 @@
 
 /*
- *  $Id: numeric.c,v 4.7 2006/09/24 02:11:16 bkorb Exp $
- *  Time-stamp:      "2006-09-22 18:14:38 bkorb"
+ *  $Id: numeric.c,v 4.10 2007/01/18 05:32:13 bkorb Exp $
+ *  Time-stamp:      "2007-01-13 10:28:20 bkorb"
  */
 
 /*
@@ -61,7 +61,7 @@ void
 optionNumericVal( tOptions* pOpts, tOptDesc* pOD )
 {
     char* pz;
-    int   val;
+    long  val;
 
     /*
      *  Numeric options may have a range associated with it.
@@ -71,12 +71,17 @@ optionNumericVal( tOptions* pOpts, tOptDesc* pOD )
     if ((pOD == NULL) || (pOD->optArg.argString == NULL))
         return;
 
-    val = (int)strtol( pOD->optArg.argString, &pz, 0 );
+    val = strtol( pOD->optArg.argString, &pz, 0 );
     if (*pz != NUL) {
         fprintf( stderr, zNotNumber, pOpts->pzProgName, pOD->optArg.argString );
         (*(pOpts->pUsageProc))(pOpts, EXIT_FAILURE);
     }
 
+    if (pOD->fOptState & OPTST_ALLOC_ARG) {
+        AGFREE(pOD->optArg.argString);
+        pOD->fOptState &= ~OPTST_ALLOC_ARG;
+    }
+
     pOD->optArg.argInt = val;
 }
 /*
