@@ -1,7 +1,7 @@
 
 /*
- *  restore.c  $Id: restore.c,v 4.6 2006/09/24 02:11:16 bkorb Exp $
- * Time-stamp:      "2005-02-23 15:10:20 bkorb"
+ *  restore.c  $Id: restore.c,v 4.9 2007/01/18 05:32:13 bkorb Exp $
+ * Time-stamp:      "2007-01-13 14:13:17 bkorb"
  *
  *  This module's routines will save the current option state to memory
  *  and restore it.  If saved prior to the initial optionProcess call,
@@ -51,30 +51,77 @@
  * If you do not wish that, delete this exception notice.
  */
 
+/*
+ *  optionFixupSavedOpts  Really, it just wipes out option state for
+ *  options that are troublesome to copy.  viz., stacked strings and
+ *  hierarcicaly valued option args.  We do duplicate string args that
+ *  have been marked as allocated though.
+ */
+static void
+fixupSavedOptionArgs(tOptions* pOpts)
+{
+    tOptions* p   = pOpts->pSavedState;
+    tOptDesc* pOD = pOpts->pOptDesc;
+    int       ct  = pOpts->optCt;
+
+    /*
+     *  Make sure that allocated stuff is only referenced in the
+     *  archived copy of the data.
+     */
+    for (; ct-- > 0; pOD++)  {
+        switch (OPTST_GET_ARGTYPE(pOD->fOptState)) {
+        case OPARG_TYPE_STRING:
+            if (pOD->fOptState & OPTST_STACKED) {
+                tOptDesc* q = p->pOptDesc + (pOD - pOpts->pOptDesc);
+                q->optCookie = NULL;
+            }
+            if (pOD->fOptState & OPTST_ALLOC_ARG) {
+                tOptDesc* q = p->pOptDesc + (pOD - pOpts->pOptDesc);
+                AGDUPSTR(q->optArg.argString, pOD->optArg.argString, "arg");
+            }
+            break;
+
+        case OPARG_TYPE_HIERARCHY:
+        {
+            tOptDesc* q = p->pOptDesc + (pOD - pOpts->pOptDesc);
+            q->optCookie = NULL;
+        }
+        }
+    }
+}
+
 /*=export_func optionSaveState
  *
  * what:  saves the option state to memory
  * arg:   tOptions*, pOpts, program options descriptor
  *
- * doc:   This routine will allocate enough memory to save the current
- *        option processing state.  If this routine has been called before,
- *        that memory will be reused.  You may only save one copy of the
- *        option state.  This routine may be called before optionProcess(3AO).
- *        If you do call it before the first call to optionProcess, then
- *        you may also change the contents of argc/argv after you call
- *        optionRestore(3AO)
+ * doc:
+ *
+ *  This routine will allocate enough memory to save the current option
+ *  processing state.  If this routine has been called before, that memory
+ *  will be reused.  You may only save one copy of the option state.  This
+ *  routine may be called before optionProcess(3AO).  If you do call it
+ *  before the first call to optionProcess, then you may also change the
+ *  contents of argc/argv after you call optionRestore(3AO)
+ *
+ *  In fact, more strongly put: it is safest to only use this function
+ *  before having processed any options.  In particular, the saving and
+ *  restoring of stacked string arguments and hierarchical values is
+ *  disabled.  The values are not saved.
  *
  * err:   If it fails to allocate the memory,
  *        it will print a message to stderr and exit.
  *        Otherwise, it will always succeed.
 =*/
 void
-optionSaveState( tOptions* pOpts )
+optionSaveState(tOptions* pOpts)
 {
-    if (pOpts->pSavedState == NULL) {
+    tOptions* p = (tOptions*)pOpts->pSavedState;
+
+    if (p == NULL) {
         size_t sz = sizeof( *pOpts ) + (pOpts->optCt * sizeof( tOptDesc ));
-        pOpts->pSavedState = AGALOC( sz, "saved option state" );
-        if (pOpts->pSavedState == NULL) {
+        p = AGALOC( sz, "saved option state" );
+        if (p == NULL) {
             tCC* pzName = pOpts->pzProgName;
             if (pzName == NULL) {
                 pzName = pOpts->pzPROGNAME;
@@ -84,37 +131,14 @@ optionSaveState( tOptions* pOpts )
             fprintf( stderr, zCantSave, pzName, sz );
             exit( EXIT_FAILURE );
         }
+
+        pOpts->pSavedState = p;
     }
 
-    {
-        tOptions* p   = pOpts->pSavedState;
-        tOptDesc* pOD = pOpts->pOptDesc;
-        int       ct  = pOpts->optCt;
+    memcpy( p, pOpts, sizeof( *p ));
+    memcpy( p + 1, pOpts->pOptDesc, p->optCt * sizeof( tOptDesc ));
 
-        memcpy( p, pOpts, sizeof( *p ));
-        memcpy( p + 1, pOpts->pOptDesc, p->optCt * sizeof( tOptDesc ));
-
-        /*
-         *  Make sure that allocated stuff is only referenced in the
-         *  archived copy of the data.
-         */
-        for (; ct-- > 0; pOD++)  {
-            switch (OPTST_GET_ARGTYPE(pOD->fOptState)) {
-            case OPARG_TYPE_STRING:
-                if (pOD->fOptState & OPTST_STACKED) {
-                    tOptDesc* q = p->pOptDesc + (pOD - pOpts->pOptDesc);
-                    q->optCookie = NULL;
-                }
-                break;
-
-            case OPARG_TYPE_HIERARCHY:
-            {
-                tOptDesc* q = p->pOptDesc + (pOD - pOpts->pOptDesc);
-                q->optCookie = NULL;
-            }
-            }
-        }
-    }
+    fixupSavedOptionArgs(pOpts);
 }
 
 
@@ -148,8 +172,15 @@ optionRestore( tOptions* pOpts )
         fprintf( stderr, zNoState, pzName );
         exit( EXIT_FAILURE );
     }
+
+    pOpts->pSavedState = NULL;
+    optionFree(pOpts);
+
     memcpy( pOpts, p, sizeof( *p ));
     memcpy( pOpts->pOptDesc, p+1, p->optCt * sizeof( tOptDesc ));
+    pOpts->pSavedState = p;
+
+    fixupSavedOptionArgs(pOpts);
 }
 
 /* = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = = */
@@ -168,34 +199,47 @@ optionRestore( tOptions* pOpts )
 void
 optionFree( tOptions* pOpts )
 {
-    if (pOpts->pSavedState != NULL) {
-        AGFREE( pOpts->pSavedState );
-        pOpts->pSavedState = NULL;
-    }
+ free_saved_state:
     {
         tOptDesc* p = pOpts->pOptDesc;
         int ct = pOpts->optCt;
         do  {
+            if (p->fOptState & OPTST_ALLOC_ARG) {
+                AGFREE(p->optArg.argString);
+                p->optArg.argString = NULL;
+                p->fOptState &= ~OPTST_ALLOC_ARG;
+            }
+
             switch (OPTST_GET_ARGTYPE(p->fOptState)) {
             case OPARG_TYPE_STRING:
+#ifdef WITH_LIBREGEX
                 if (  (p->fOptState & OPTST_STACKED)
                    && (p->optCookie != NULL)) {
-                    AGFREE( p->optCookie );
-                    p->fOptState &= OPTST_PERSISTENT;
-                    if ((p->fOptState & OPTST_INITENABLED) == 0)
-                        p->fOptState |= OPTST_DISABLED;
+                    p->optArg.argString = ".*";
+                    optionUnstackArg(pOpts, p);
                 }
+#else
+                /* leak memory */;
+#endif
                 break;
 
             case OPARG_TYPE_HIERARCHY:
                 if (p->optCookie != NULL)
-                    optionUnloadNested(p->optCookie);
+                    unloadNestedArglist(p->optCookie);
                 break;
             }
 
             p->optCookie = NULL;
         } while (p++, --ct > 0);
     }
+    if (pOpts->pSavedState != NULL) {
+        tOptions * p = (tOptions*)pOpts->pSavedState;
+        memcpy( pOpts, p, sizeof( *p ));
+        memcpy( pOpts->pOptDesc, p+1, p->optCt * sizeof( tOptDesc ));
+        AGFREE( pOpts->pSavedState );
+        pOpts->pSavedState = NULL;
+        goto free_saved_state;
+    }
 }
 /*
  * Local Variables:
