@@ -1,7 +1,7 @@
 
 /*
- *  save.c  $Id: save.c,v 4.13 2006/11/27 01:52:23 bkorb Exp $
- * Time-stamp:      "2006-10-05 21:09:18 bkorb"
+ *  save.c  $Id: save.c,v 4.16 2007/01/18 05:32:13 bkorb Exp $
+ * Time-stamp:      "2007-01-13 10:32:27 bkorb"
  *
  *  This module's routines will take the currently set options and
  *  store them into an ".rc" file for re-interpretation the next
@@ -63,8 +63,8 @@ findFileName( tOptions* pOpts, int* p_free_name );
 
 static void
 printEntry(
-    FILE*      fp,
-    tOptDesc*  p,
+    FILE *     fp,
+    tOptDesc * p,
     tCC*       pzLA );
 /* = = = END-STATIC-FORWARD = = = */
 
@@ -270,16 +270,25 @@ findFileName( tOptions* pOpts, int* p_free_name )
 
 static void
 printEntry(
-    FILE*      fp,
-    tOptDesc*  p,
+    FILE *     fp,
+    tOptDesc * p,
     tCC*       pzLA )
 {
     /*
-     *  There is an argument.  Pad the name so values line up
+     *  There is an argument.  Pad the name so values line up.
+     *  Not disabled *OR* this got equivalenced to another opt,
+     *  then use current option name.
+     *  Otherwise, there must be a disablement name.
      */
-    fprintf( fp, "%-18s",
-             (DISABLED_OPT( p )) ? p->pz_DisableName : p->pz_Name );
+    {
+        char const * pz;
+        if (! DISABLED_OPT(p) || (p->optEquivIndex != NO_EQUIVALENT))
+            pz = p->pz_Name;
+        else
+            pz = p->pz_DisableName;
 
+        fprintf(fp, "%-18s", pz);
+    }
     /*
      *  IF the option is numeric only,
      *  THEN the char pointer is really the number
@@ -469,12 +478,16 @@ optionSaveFile( tOptions* pOpts )
              */
             (*(p->pOptProc))( (tOptions*)2UL, p );
             printEntry( fp, p, (void*)(p->optArg.argString));
+
             if (  (p->optArg.argString != NULL)
-               && (arg_state != OPARG_TYPE_ENUMERATION))
+               && (arg_state != OPARG_TYPE_ENUMERATION)) {
                 /*
-                 *  bit flag and enumeration strings get allocated
+                 *  set membership strings get allocated
                  */
                 AGFREE( (void*)p->optArg.argString );
+                p->fOptState &= ~OPTST_ALLOC_ARG;
+            }
+
             p->optArg.argEnum = val;
             break;
         }
