@@ -37,6 +37,10 @@
 
 #include <stddef.h>
 
+#if HAVE_RUNETYPE_H
+# include <runetype.h>
+#endif
+
 #ifdef HAVE_WCHAR_H
 #  include <wchar.h>
 #endif
@@ -127,7 +131,7 @@ printf_generic (STREAM *stream, struct printf_info *const pinfo, union printf_ar
     }
 
   /* Print to a stream using a user-supplied function. */
-  fil = filnew (NULL, 0);
+  fil = filnew (NULL, (size_t)0);
   out = stream_new (fil, SNV_UNLIMITED, NULL, snv_filputc);
   user_func (out, pinfo, args);
   stream_delete (out);
